@@ -13,14 +13,20 @@
 #' @export
 
 lat.lang <- function(x, glottolog.source = "modified") {
-  if(typeof(x) == "list"){x <- unlist(x)}
-  ifelse(grepl(glottolog.source, "original"),
-         glottolog <- lingtypology::glottolog.original,
-         glottolog <- lingtypology::glottolog.modified)
+  if (typeof(x) == "list") {
+    x <- unlist(x)
+  }
+  ifelse(
+    grepl(glottolog.source, "original"),
+    glottolog <- lingtypology::glottolog.original,
+    glottolog <- lingtypology::glottolog.modified
+  )
   vapply(x, function(y) {
-    ifelse(is.glottolog(y, response = TRUE,
-                        glottolog.source = glottolog.source) == TRUE,
-           glottolog[tolower(glottolog$language) %in% tolower(y), ]$latitude,
-           NA_real_)
+    ifelse(
+      is.glottolog(y, response = TRUE,
+                   glottolog.source = glottolog.source) == TRUE,
+      glottolog[tolower(glottolog$language) %in% tolower(y),]$latitude,
+      NA_real_
+    )
   }, double(1))
 }
